# GS Quant

**GS Quant** is a Python toolkit for quantitative finance, created on top of one of the world’s most powerful risk transfer platforms. Designed to accelerate development of quantitative trading strategies and risk management solutions, crafted over 25 years of experience navigating global markets.

It is created and maintained by quantitative developers (quants) at Goldman Sachs to enable the development of trading strategies and analysis of derivative products. GS Quant can be used to facilitate derivative structuring, trading, and risk management, or as a set of statistical packages for data analytics applications.

In order to access the APIs you will need a client id and secret.  These are available to institutional clients of Goldman Sachs.  Please speak to your sales coverage or Marquee Sales for further information. 

Please refer to [Goldman Sachs Developer](https://developer.gs.com/docs/gsquant/) for additional information.

## Requirements

* Python 3.9 or greater
* Access to PIP package manager

## Installation

```
pip install gs-quant
```

## Examples

You can find examples, guides and tutorials in the respective folders on [Goldman Sachs Developer](https://developer.gs.com/docs/gsquant/).


## Help

Please reach out to `gs-quant@gs.com` with any questions, comments or feedback.
